﻿using System;
using System.Diagnostics;


namespace SpaceInvaders
{
    public class Font : DLink
    {
        //-------------------------------------------------------------------
        //  FIELDS
        //-------------------------------------------------------------------

        public enum FontName
        {
            Attract_Title,
            Attract_Play,
            Attract_ScoreTable,
            Attract_Ufo,
            Attract_Squid,
            Attract_Crab,
            Attract_Jellyfish,
            Attract_Player1,
            Attract_Player2,
            Attract_PlayerSelect,

            HighScore_Title,
            P1_Score_Title,
            P2_Score_Title,
            HighScore,
            P1_Score,
            P2_Score,
            PlayerLife,

            GameCredits,
            GameOver,

            Message,
            NullObject,
            Uninitialized
        }

        public FontName name;
        public SpriteFont pSpriteFont;
        private static readonly string pNullString = "null";


        //-------------------------------------------------------------------
        //  CONSTRUCTION
        //-------------------------------------------------------------------

        public Font() : base()
        {
            this.name = FontName.Uninitialized;
            this.pSpriteFont = new SpriteFont();
        }


        //-------------------------------------------------------------------
        //  PUBLIC METHODS
        //-------------------------------------------------------------------

        public void SetFont(Font.FontName name, string pMessage, Glyph.GlyphName glyphName, float x, float y)
        {
            Debug.Assert(pMessage != null);

            this.name = name;
            this.pSpriteFont.SetSpriteFont(name, pMessage, glyphName, x, y);
        }

        public void SetFont(Font.FontName fontName, Glyph.GlyphName glyphName, string message, float x, float y, float sx, float sy, float spacing, Azul.Color color)
        {
            Debug.Assert(message != null);

            this.name = fontName;
            this.pSpriteFont.SetSpriteFont(fontName, glyphName, message, x, y, sx, sy, spacing, color);
        }

        public void UpdateMessage(string pMessage)
        {
            Debug.Assert(pMessage != null);
            Debug.Assert(this.pSpriteFont != null);

            this.pSpriteFont.UpdateMessage(pMessage);
        }

        public override bool Compare(Node pNode)
        {
            Debug.Assert(pNode != null);
            
            Font pFontB = (Font)pNode;
            if(this.name == pFontB.name)
            {
                return true;
            }

            return false;
        }

        public override object GetName()
        {
            return this.name;
        }

        public override void Reset()
        {
            this.Clear();
        }

        public override void PrintStats()
        {
            Debug.WriteLine("{0} {1}", this.name, this.GetHashCode());

            base.PrintStats();
        }


        //-------------------------------------------------------------------
        //  PRIVATE METHODS
        //-------------------------------------------------------------------

        private void Clear()
        {
            this.name = FontName.Uninitialized;
            this.pSpriteFont.SetSpriteFont(FontName.NullObject, pNullString, Glyph.GlyphName.NullObject, 0.0f, 0.0f);
        }


    } // end class

} // end namespace